import { ReactNode, FC } from 'react';
/**
 * @typedef {Object} EventContextType
 * @template E - The type of the event name, defaults to string.
 * @template D - The type of the event data, defaults to a record with string keys and any values.
 *
 * @property {function(E, D): void} handleUserAction - Function to handle user actions.
 * @property {function(E, D, boolean=): void} handleResponseAction - Function to handle response actions, with an optional error flag.
 * @property {function(string[], string[], string=): function} addGlobalListeners - Function to add global event listeners.
 *   @param {string[]} eventTypes - Array of event types to listen for.
 *   @param {string[]} dataAttributes - Array of data attributes to capture.
 *   @param {string} [selector] - Optional CSS selector to limit the scope of the listeners.
 *   @returns {function} - A function to remove the added listeners.
 */
export type EventContextType<E = string, D = Record<string, any>> = {
    handleUserAction: (eventName: E, eventData: D) => void;
    handleResponseAction: (eventName: E, eventData: D, error?: boolean) => void;
    addGlobalListeners: (eventTypes: string[], dataAttributes: string[], selector?: string) => () => void;
};
export type EventProviderProps = {
    children: ReactNode;
};
/**
 * EventProvider component that provides event handling capabilities to its children.
 *
 * @param {EventProviderProps} props - The properties for the EventProvider component.
 * @param {React.ReactNode} props.children - The child components that will be wrapped by the EventProvider.
 *
 * @returns {JSX.Element} The EventProvider component.
 *
 * @description
 * This component sets up event handling for user actions and response actions. It uses the Context API to provide
 * event handling functions to its children. The event handling functions include:
 *
 * - `handleUserAction`: Sends a user action event with the specified event name and data.
 * - `handleResponseAction`: Sends a response action event with the specified event name, data, and an optional error flag.
 * - `addGlobalListeners`: Adds global event listeners for specified event types and a selector, and extracts data attributes
 *   from the event target to send as event data.
 *
 * The event data is sent to a service worker if it is available and controlled.
 *
 * @example
 * ```tsx
 * import { EventProvider } from './context/CaptureEventProvider';
 *
 * const App = () => (
 *   <EventProvider>
 *     <YourComponent />
 *   </EventProvider>
 * );
 * ```
 */
export declare const EventProvider: FC<EventProviderProps>;
/**
 * Custom hook to access the event context.
 *
 * This hook provides access to the event context, which includes event data and dispatch functions.
 * It must be used within an `EventProvider` to function correctly.
 *
 * @template E - The type of the event name. Defaults to `string`.
 * @template D - The type of the event data. Defaults to `Record<string, any>`.
 *
 * @returns {EventContextType<E, D>} The event context, typed with the provided event name and data types.
 *
 * @throws {Error} If the hook is used outside of an `EventProvider`.
 */
export declare const useCaptureEvent: <E = string, D = Record<string, any>>() => EventContextType<E, D>;
